#[non_exhaustive]pub enum ConversionErrorKind {
FailedToUnescape(EscapeError),
InvalidLiteralKind,
}🔬This is a nightly-only experimental API. (
proc_macro_value #136652)Expand description
Errors returned when trying to retrieve a literal unescaped value.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailedToUnescape(EscapeError)
🔬This is a nightly-only experimental API. (
proc_macro_value #136652)The literal failed to be escaped, take a look at EscapeError for more information.
InvalidLiteralKind
🔬This is a nightly-only experimental API. (
proc_macro_value #136652)Trying to convert a literal with the wrong type.