Punct

Struct Punct 

1.29.0 · Source
pub struct Punct(pub(crate) Punct<Span>);
A Punct is a single punctuation character such as +, - or #.

Multi-character operators like += are represented as two instances of Punct with different forms of Spacing returned.

Tuple Fields

0: Punct<Span>

Implementations

Source

impl Punct

1.29.0 · Source

pub fn new(ch: char, spacing: Spacing) -> Punct

Creates a new Punct from the given character and spacing. The ch argument must be a valid punctuation character permitted by the language, otherwise the function will panic.

The returned Punct will have the default span of Span::call_site() which can be further configured with the set_span method below.

1.29.0 · Source

pub fn as_char(&self) -> char

Returns the value of this punctuation character as char.

1.29.0 · Source

pub fn spacing(&self) -> Spacing

Returns the spacing of this punctuation character, indicating whether it can be potentially combined into a multi-character operator with the following token (Joint), or whether the operator has definitely ended (Alone).

1.29.0 · Source

pub fn span(&self) -> Span

Returns the span for this punctuation character.

1.29.0 · Source

pub fn set_span(&mut self, span: Span)

Configure the span for this punctuation character.