#[non_exhaustive]pub enum EscapeError {
Show 23 variants
ZeroChars,
MoreThanOneChar,
LoneSlash,
InvalidEscape,
BareCarriageReturn,
BareCarriageReturnInRawString,
EscapeOnlyChar,
TooShortHexEscape,
InvalidCharInHexEscape,
OutOfRangeHexEscape,
NoBraceInUnicodeEscape,
InvalidCharInUnicodeEscape,
EmptyUnicodeEscape,
UnclosedUnicodeEscape,
LeadingUnderscoreUnicodeEscape,
OverlongUnicodeEscape,
LoneSurrogateUnicodeEscape,
OutOfRangeUnicodeEscape,
UnicodeEscapeInByte,
NonAsciiCharInByte,
NulInCStr,
UnskippedWhitespaceWarning,
MultipleSkippedLinesWarning,
}proc_macro_value #136652)Expand description
Mostly relating to malformed escape sequences, but also a few other problems.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ZeroChars
proc_macro_value #136652)Expected 1 char, but 0 were found.
MoreThanOneChar
proc_macro_value #136652)Expected 1 char, but more than 1 were found.
LoneSlash
proc_macro_value #136652)Escaped ’' character without continuation.
InvalidEscape
proc_macro_value #136652)Invalid escape character (e.g. ‘\z’).
BareCarriageReturn
proc_macro_value #136652)Raw ‘\r’ encountered.
BareCarriageReturnInRawString
proc_macro_value #136652)Raw ‘\r’ encountered in raw string.
EscapeOnlyChar
proc_macro_value #136652)Unescaped character that was expected to be escaped (e.g. raw ‘\t’).
TooShortHexEscape
proc_macro_value #136652)Numeric character escape is too short (e.g. ‘\x1’).
InvalidCharInHexEscape
proc_macro_value #136652)Invalid character in numeric escape (e.g. ‘\xz’)
OutOfRangeHexEscape
proc_macro_value #136652)Character code in numeric escape is non-ascii (e.g. ‘\xFF’).
NoBraceInUnicodeEscape
proc_macro_value #136652)‘\u’ not followed by ‘{’.
InvalidCharInUnicodeEscape
proc_macro_value #136652)Non-hexadecimal value in ‘\u{..}’.
EmptyUnicodeEscape
proc_macro_value #136652)‘\u{}’
UnclosedUnicodeEscape
proc_macro_value #136652)No closing brace in ‘\u{..}’, e.g. ‘\u{12’.
LeadingUnderscoreUnicodeEscape
proc_macro_value #136652)‘\u{_12}’
OverlongUnicodeEscape
proc_macro_value #136652)More than 6 characters in ‘\u{..}’, e.g. ‘\u{10FFFF_FF}’
LoneSurrogateUnicodeEscape
proc_macro_value #136652)Invalid in-bound unicode character code, e.g. ‘\u{DFFF}’.
OutOfRangeUnicodeEscape
proc_macro_value #136652)Out of bounds unicode character code, e.g. ‘\u{FFFFFF}’.
UnicodeEscapeInByte
proc_macro_value #136652)Unicode escape code in byte literal.
NonAsciiCharInByte
proc_macro_value #136652)Non-ascii character in byte literal, byte string literal, or raw byte string literal.
NulInCStr
proc_macro_value #136652)\0 in a C string literal.
UnskippedWhitespaceWarning
proc_macro_value #136652)After a line ending with ’', the next line contains whitespace characters that are not skipped.
MultipleSkippedLinesWarning
proc_macro_value #136652)After a line ending with ’', multiple lines are skipped.