pub struct Punct(pub(crate) Punct<Span>);Expand description
A Punct is a single punctuation character such as +, - or #.
Multi-character operators like += are represented as two instances of Punct with different
forms of Spacing returned.
Tuple Fields
0: Punct<Span>Implementations
Sourceimpl Punct
impl Punct
1.29.0 · Sourcepub fn new(ch: char, spacing: Spacing) -> Punct
pub fn new(ch: char, spacing: Spacing) -> Punct
Creates a new Punct from the given character and spacing.
The ch argument must be a valid punctuation character permitted by the language,
otherwise the function will panic.
The returned Punct will have the default span of Span::call_site()
which can be further configured with the set_span method below.
1.29.0 · Sourcepub fn as_char(&self) -> char
pub fn as_char(&self) -> char
Returns the value of this punctuation character as char.